AtomicFnPtr

Struct AtomicFnPtr 

#[repr(transparent)]
pub struct AtomicFnPtr { inner: AtomicPtr<c_void>, }

Fields

inner: AtomicPtr<c_void>

Safety

See the module docs:

  • The actual type must never change.
  • The actual type must be a function pointer implementing super::FnPtrLike.

Implementations

Source

impl AtomicFnPtr

pub(super) const fn new(f: ErasedFnPtr) -> Self

pub(super) unsafe fn store_relaxed(&self, f: ErasedFnPtr)

SAFETY

The passed argument must have the same actual type as self.

pub(super) fn load_relaxed(&self) -> ErasedFnPtr